==> jc-1.4.0.tar.gz: javax/security/sasl/AuthorizeCallback.h <==
// public class javax.security.sasl.AuthorizeCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 20ace6e25dfd4dfa javax_security_sasl_AuthorizeCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_sasl_AuthorizeCallback_H_
#define _JC_javax_security_sasl_AuthorizeCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_AuthorizeCallback$sub_refs	_jc_javax_security_sasl_AuthorizeCallback$sub_refs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs	_jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$refs	_jc_javax_security_sasl_AuthorizeCallback$refs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$nonrefs	_jc_javax_security_sasl_AuthorizeCallback$nonrefs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$object	_jc_javax_security_sasl_AuthorizeCallback$object;

typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vmethods	_jc_javax_security_sasl_AuthorizeCallback$vmethods;
typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vtable	_jc_javax_security_sasl_AuthorizeCallback$vtable;
typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vtype	_jc_javax_security_sasl_AuthorizeCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_AuthorizeCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthenticationID$90514d847346e86b(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthorizationID$ef3a46e8cdf61c67(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthorizedID$0430fbcc008ba1bb(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
extern jboolean _jc_javax_security_sasl_AuthorizeCallback$method$isAuthorized$20d9e2a50060f081(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
extern void _jc_javax_security_sasl_AuthorizeCallback$method$setAuthorized$cf1f2fc0688ecdce(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, jboolean);
extern void _jc_javax_security_sasl_AuthorizeCallback$method$setAuthorizedID$2ef44e118666517d(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_sasl_AuthorizeCallback$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthenticationID$90514d847346e86b;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthorizationID$ef3a46e8cdf61c67;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthorizedID$0430fbcc008ba1bb;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$isAuthorized$20d9e2a50060f081;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$setAuthorized$cf1f2fc0688ecdce;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$setAuthorizedID$2ef44e118666517d;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_security_sasl_AuthorizeCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getAuthenticationID$90514d847346e86b)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
	struct _jc_java_lang_String$object	*(*getAuthorizationID$ef3a46e8cdf61c67)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
	struct _jc_java_lang_String$object	*(*getAuthorizedID$0430fbcc008ba1bb)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
	jboolean	(*isAuthorized$20d9e2a50060f081)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
	void	(*setAuthorized$cf1f2fc0688ecdce)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, jboolean);
	void	(*setAuthorizedID$2ef44e118666517d)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *);
};

// Vtable
struct _jc_javax_security_sasl_AuthorizeCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_sasl_AuthorizeCallback$vmethods	javax_security_sasl_AuthorizeCallback;
};

// Vtype
struct _jc_javax_security_sasl_AuthorizeCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_AuthorizeCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthorizeCallback$sub_refs {
	struct _jc_java_lang_String$object	*authenticationID;
	struct _jc_java_lang_String$object	*authorizationID;
	struct _jc_java_lang_String$object	*authorizedID;
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_AuthorizeCallback$refs {
    _jc_javax_security_sasl_AuthorizeCallback$sub_refs	javax_security_sasl_AuthorizeCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs {
	jboolean	authorized;
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_AuthorizeCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs	javax_security_sasl_AuthorizeCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_AuthorizeCallback$object {
	_jc_javax_security_sasl_AuthorizeCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_AuthorizeCallback$vtype	*vtype;
	_jc_javax_security_sasl_AuthorizeCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_AuthorizeCallback$vtype _jc_javax_security_sasl_AuthorizeCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_AuthorizeCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_AuthorizeCallback$class_object;

#endif	/* _JC_javax_security_sasl_AuthorizeCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/AuthorizeCallback.h <==
// public class javax.security.sasl.AuthorizeCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 20ace6e25dfd4dfa javax_security_sasl_AuthorizeCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_sasl_AuthorizeCallback_H_
#define _JC_javax_security_sasl_AuthorizeCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_AuthorizeCallback$sub_refs	_jc_javax_security_sasl_AuthorizeCallback$sub_refs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs	_jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$refs	_jc_javax_security_sasl_AuthorizeCallback$refs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$nonrefs	_jc_javax_security_sasl_AuthorizeCallback$nonrefs;
typedef struct _jc_javax_security_sasl_AuthorizeCallback$object	_jc_javax_security_sasl_AuthorizeCallback$object;

typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vmethods	_jc_javax_security_sasl_AuthorizeCallback$vmethods;
typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vtable	_jc_javax_security_sasl_AuthorizeCallback$vtable;
typedef const struct _jc_javax_security_sasl_AuthorizeCallback$vtype	_jc_javax_security_sasl_AuthorizeCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_AuthorizeCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthenticationID$90514d847346e86b(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthorizationID$ef3a46e8cdf61c67(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_AuthorizeCallback$method$getAuthorizedID$0430fbcc008ba1bb(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_security_sasl_AuthorizeCallback$method$isAuthorized$20d9e2a50060f081(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_AuthorizeCallback$method$setAuthorized$cf1f2fc0688ecdce(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_AuthorizeCallback$method$setAuthorizedID$2ef44e118666517d(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_AuthorizeCallback$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthenticationID$90514d847346e86b;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthorizationID$ef3a46e8cdf61c67;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$getAuthorizedID$0430fbcc008ba1bb;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$isAuthorized$20d9e2a50060f081;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$setAuthorized$cf1f2fc0688ecdce;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$setAuthorizedID$2ef44e118666517d;
extern _jc_method _jc_javax_security_sasl_AuthorizeCallback$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_security_sasl_AuthorizeCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getAuthenticationID$90514d847346e86b)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAuthorizationID$ef3a46e8cdf61c67)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAuthorizedID$0430fbcc008ba1bb)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
	jboolean	(*isAuthorized$20d9e2a50060f081)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
	void	(*setAuthorized$cf1f2fc0688ecdce)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, jboolean) _JC_JCNI_ATTR;
	void	(*setAuthorizedID$2ef44e118666517d)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_security_sasl_AuthorizeCallback$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_sasl_AuthorizeCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_sasl_AuthorizeCallback$vmethods	javax_security_sasl_AuthorizeCallback;
};

// Vtype
struct _jc_javax_security_sasl_AuthorizeCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_AuthorizeCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthorizeCallback$sub_refs {
	struct _jc_java_lang_String$object	*authenticationID;
	struct _jc_java_lang_String$object	*authorizationID;
	struct _jc_java_lang_String$object	*authorizedID;
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_AuthorizeCallback$refs {
    _jc_javax_security_sasl_AuthorizeCallback$sub_refs	javax_security_sasl_AuthorizeCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs {
	jboolean	authorized;
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_AuthorizeCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_sasl_AuthorizeCallback$sub_nonrefs	javax_security_sasl_AuthorizeCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_AuthorizeCallback$object {
	_jc_javax_security_sasl_AuthorizeCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_AuthorizeCallback$vtype	*vtype;
	_jc_javax_security_sasl_AuthorizeCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_AuthorizeCallback$vtype _jc_javax_security_sasl_AuthorizeCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_AuthorizeCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_AuthorizeCallback$class_object;

#endif	/* _JC_javax_security_sasl_AuthorizeCallback_H_ */
